@@ -17,7 +17,7 @@ from .schema import (
 )
 from .utils import concunrrently_handle_tasks
 
-document = Path("./src/bluetree_shopify_book/document.graphql").read_text()
+document = (Path(__file__).resolve().parent / "document.graphql").read_text()
 
 
 class ShopifyBookService:
